GAM is a command line tool for Google Workspace admins to manage domain and user settings quickly and easily.

[![Build StatusM](https://github.com/GAM-team/GAM/actions/workflows/build.yml/badge.svg)](https://github.com/GAM-team/GAM/actions/workflows/build.yml)

# Quick Start

## Linux / MacOS

Open a terminal and run:

```sh
bash <(curl -s -S -L https://gam-shortn.appspot.com/gam-install)
```

this will download GAM, install it and start setup.

## Windows

Download the MSI Installer from the [GitHub Releases] page. Install the MSI and you'll be prompted to setup GAM.

# Documentation

The GAM documentation is hosted in the [GitHub Wiki]

# Mailing List / Discussion group

The GAM mailing list / discussion group is hosted on [Google Groups].  You can join the list and interact via email, or just post from the web itself.

# Chat Room

There is a public chat room hosted in Google Chat. [Instructions to join](https://github.com/GAM-team/GAM/wiki/GAM-Public-Chat-Room).

# Author

GAM is maintained by [Jay (James) Lee](mailto:jay0lee@gmail.com) and [Ross Scroggs](mailto:ross.scroggs@gmail.com). Please direct "how do I?" questions to [Google Groups].

[GAM release]: https://github.com/GAM-team/GAM/releases
[GitHub Releases]: https://github.com/GAM-team/GAM/releases
[GitHub]: https://github.com/GAM-team/GAM/tree/master
[GitHub Wiki]: https://github.com/GAM-team/GAM/wiki/
[Google Groups]: http://groups.google.com/group/google-apps-manager
